package com.ruoyi.brewery.service;

import java.util.List;
import com.ruoyi.brewery.domain.WyBreweryBanner;

/**
 * 品牌方广告图Service接口
 * 
 * @author ruoyi
 * @date 2024-12-21
 */
public interface IWyBreweryBannerService 
{
    /**
     * 查询品牌方广告图
     * 
     * @param id 品牌方广告图主键
     * @return 品牌方广告图
     */
    public WyBreweryBanner selectWyBreweryBannerById(Long id);

    /**
     * 查询品牌方广告图列表
     * 
     * @param wyBreweryBanner 品牌方广告图
     * @return 品牌方广告图集合
     */
    public List<WyBreweryBanner> selectWyBreweryBannerList(WyBreweryBanner wyBreweryBanner);

    /**
     * 新增品牌方广告图
     * 
     * @param wyBreweryBanner 品牌方广告图
     * @return 结果
     */
    public int insertWyBreweryBanner(WyBreweryBanner wyBreweryBanner);

    /**
     * 修改品牌方广告图
     * 
     * @param wyBreweryBanner 品牌方广告图
     * @return 结果
     */
    public int updateWyBreweryBanner(WyBreweryBanner wyBreweryBanner);

    /**
     * 批量删除品牌方广告图
     * 
     * @param ids 需要删除的品牌方广告图主键集合
     * @return 结果
     */
    public int deleteWyBreweryBannerByIds(Long[] ids);

    /**
     * 删除品牌方广告图信息
     * 
     * @param id 品牌方广告图主键
     * @return 结果
     */
    public int deleteWyBreweryBannerById(Long id);
}
